@@ -8,6 +8,7 @@
 module Command (
 	command,
 	noRepo,
+	withOptions,
 	next,
 	stop,
 	stopUnless,
@@ -25,23 +26,28 @@ import Common.Annex
 import qualified Backend
 import qualified Annex
 import qualified Git
+import qualified Remote
 import Types.Command as ReExported
+import Types.Option as ReExported
 import Seek as ReExported
 import Checks as ReExported
-import Options as ReExported
+import Usage as ReExported
 import Logs.Trust
-import Logs.Location
 import Config
 
 {- Generates a normal command -}
 command :: String -> String -> [CommandSeek] -> String -> Command
-command = Command Nothing commonChecks
+command = Command [] Nothing commonChecks
 
 {- Adds a fallback action to a command, that will be run if it's used
  - outside a git repository. -}
 noRepo :: IO () -> Command -> Command
 noRepo a c = c { cmdnorepo = Just a }
 
+{- Adds options to a command. -}
+withOptions :: [Option] -> Command -> Command
+withOptions o c = c { cmdoptions = o }
+
 {- For start and perform stages to indicate what step to run next. -}
 next :: a -> Annex (Maybe a)
 next a = return $ Just a
@@ -77,10 +83,10 @@ doCommand = start
 
 {- Modifies an action to only act on files that are already annexed,
  - and passes the key and backend on to it. -}
-whenAnnexed :: (FilePath -> (Key, Backend Annex) -> Annex (Maybe a)) -> FilePath -> Annex (Maybe a)
+whenAnnexed :: (FilePath -> (Key, Backend) -> Annex (Maybe a)) -> FilePath -> Annex (Maybe a)
 whenAnnexed a file = ifAnnexed file (a file) (return Nothing)
 
-ifAnnexed :: FilePath -> ((Key, Backend Annex) -> Annex a) -> Annex a -> Annex a
+ifAnnexed :: FilePath -> ((Key, Backend) -> Annex a) -> Annex a -> Annex a
 ifAnnexed file yes no = maybe no yes =<< Backend.lookupFile file
 
 notBareRepo :: Annex a -> Annex a
@@ -104,5 +110,5 @@ autoCopies key vs numcopiesattr a = Annex.getState Annex.auto >>= auto
 		auto False = a
 		auto True = do
 			needed <- getNumCopies numcopiesattr
-			(_, have) <- trustPartition UnTrusted =<< keyLocations key
+			(_, have) <- trustPartition UnTrusted =<< Remote.keyLocations key
 			if length have `vs` needed then a else stop
