@@ -7,23 +7,20 @@
 
 module Command.RecvKey where
 
-import Control.Monad.State (liftIO)
-import System.Exit
-
+import Common.Annex
 import Command
 import CmdLine
-import Content
-import Utility
+import Annex.Content
 import Utility.RsyncFile
 
-command :: [Command]
-command = [repoCommand "recvkey" paramKey seek
+def :: [Command]
+def = [command "recvkey" paramKey seek
 	"runs rsync in server mode to receive content"]
 
 seek :: [CommandSeek]
 seek = [withKeys start]
 
-start :: CommandStartKey
+start :: Key -> CommandStart
 start key = do
 	whenM (inAnnex key) $ error "key is already present in annex"
 	
