@@ -24,11 +24,16 @@ start :: [FilePath] -> CommandStart
 start (src:dest:[])
 	| src == dest = stop
 	| otherwise = do
-		showStart "reinject" dest
-		next $ whenAnnexed (perform src) dest
+		ifAnnexed src
+			(error $ "cannot used annexed file as src: " ++ src)
+			go
+	where
+		go = do
+			showStart "reinject" dest
+			next $ whenAnnexed (perform src) dest
 start _ = error "specify a src file and a dest file"
 
-perform :: FilePath -> FilePath -> (Key, Backend Annex) -> CommandPerform
+perform :: FilePath -> FilePath -> (Key, Backend) -> CommandPerform
 perform src _dest (key, backend) = do
 	unlessM move $ error "mv failed!"
 	next $ cleanup key backend
@@ -40,7 +45,7 @@ perform src _dest (key, backend) = do
 		move = getViaTmp key $ \tmp ->
 			liftIO $ boolSystem "mv" [File src, File tmp]
 
-cleanup :: Key -> Backend Annex -> CommandCleanup
+cleanup :: Key -> Backend -> CommandCleanup
 cleanup key backend = do
 	logStatus key InfoPresent
 
