@@ -8,7 +8,6 @@
 module Command.Whereis where
 
 import Common.Annex
-import Logs.Location
 import Command
 import Remote
 import Logs.Trust
@@ -20,7 +19,7 @@ def = [command "whereis" paramPaths seek
 seek :: [CommandSeek]
 seek = [withFilesInGit $ whenAnnexed start]
 
-start :: FilePath -> (Key, Backend Annex) -> CommandStart
+start :: FilePath -> (Key, Backend) -> CommandStart
 start file (key, _) = do
 	showStart "whereis" file
 	next $ perform key
