@@ -20,7 +20,7 @@ import Remote.Helper.Special
 import Remote.Helper.Encryptable
 import Crypto
 
-remote :: RemoteType Annex
+remote :: RemoteType
 remote = RemoteType {
 	typename = "hook",
 	enumerate = findSpecialRemotes "hooktype",
@@ -28,7 +28,7 @@ remote = RemoteType {
 	setup = hookSetup
 }
 
-gen :: Git.Repo -> UUID -> Maybe RemoteConfig -> Annex (Remote Annex)
+gen :: Git.Repo -> UUID -> Maybe RemoteConfig -> Annex Remote
 gen r u c = do
 	hooktype <- getConfig r "hooktype" (error "missing hooktype")
 	cst <- remoteCost r expensiveRemoteCost
@@ -45,7 +45,8 @@ gen r u c = do
 			hasKey = checkPresent r hooktype,
 			hasKeyCheap = False,
 			config = Nothing,
-			repo = r
+			repo = r,
+			remotetype = remote
 		}
 
 hookSetup :: UUID -> RemoteConfig -> Annex RemoteConfig
@@ -62,13 +63,12 @@ hookEnv k f = Just $ fileenv f ++ keyenv
 		env s v = ("ANNEX_" ++ s, v)
 		keyenv =
 			[ env "KEY" (show k)
-			, env "HASH_1" hash_1
-			, env "HASH_2" hash_2
+			, env "HASH_1" (hashbits !! 0)
+			, env "HASH_2" (hashbits !! 1)
 			]
 		fileenv Nothing = []
 		fileenv (Just file) =  [env "FILE" file]
-		[hash_1, hash_2, _rest] =
-			map takeDirectory $ splitPath $ hashDirMixed k
+		hashbits = map takeDirectory $ splitPath $ hashDirMixed k
 
 lookupHook :: String -> String -> Annex (Maybe String)
 lookupHook hooktype hook =do
