@@ -10,11 +10,13 @@ module Remote.Web (remote) where
 import Common.Annex
 import Types.Remote
 import qualified Git
+import qualified Git.Construct
+import Annex.Content
 import Config
 import Logs.Web
 import qualified Utility.Url as Url
 
-remote :: RemoteType Annex
+remote :: RemoteType
 remote = RemoteType {
 	typename = "web",
 	enumerate = list,
@@ -26,9 +28,11 @@ remote = RemoteType {
 -- (If the web should cease to exist, remove this module and redistribute
 -- a new release to the survivors by carrier pigeon.)
 list :: Annex [Git.Repo]
-list = return [Git.repoRemoteNameSet "web" Git.repoFromUnknown]
+list = do
+	r <- liftIO $ Git.Construct.remoteNamed "web" Git.Construct.fromUnknown
+	return [r]
 
-gen :: Git.Repo -> UUID -> Maybe RemoteConfig -> Annex (Remote Annex)
+gen :: Git.Repo -> UUID -> Maybe RemoteConfig -> Annex Remote
 gen r _ _ = 
 	return Remote {
 		uuid = webUUID,
@@ -40,7 +44,8 @@ gen r _ _ =
 		hasKey = checkKey,
 		hasKeyCheap = False,
 		config = Nothing,
-		repo = r
+		repo = r,
+		remotetype = remote
 	}
 
 downloadKey :: Key -> FilePath -> Annex Bool
@@ -51,7 +56,7 @@ downloadKey key file = get =<< getUrls key
 			return False
 		get urls = do
 			showOutput -- make way for download progress bar
-			liftIO $ anyM (`Url.download` file) urls
+			downloadUrl urls file
 
 uploadKey :: Key -> Annex Bool
 uploadKey _ = do
