@@ -32,14 +32,15 @@ type CommandPerform = Annex (Maybe CommandCleanup)
 type CommandCleanup = Annex Bool
 
 {- A command is defined by specifying these things. -}
-data Command = Command {
-	cmdnorepo :: Maybe (IO ()),
-	cmdcheck :: [CommandCheck],
-	cmdname :: String,
-	cmdparams :: String,
-	cmdseek :: [CommandSeek],
-	cmddesc :: String
-}
+data Command = Command
+	{ cmdoptions :: [Option]     -- command-specific options
+	, cmdnorepo :: Maybe (IO ()) -- an action to run when not in a repo
+	, cmdcheck :: [CommandCheck] -- check stage
+	, cmdname :: String
+	, cmdparamdesc :: String     -- description of params for usage
+	, cmdseek :: [CommandSeek]   -- seek stage
+	, cmddesc :: String          -- description of command for usage
+	}
 
 {- CommandCheck functions can be compared using their unique id. -}
 instance Eq CommandCheck where
